abacusai.feature_distribution — AbacusAI documentation

# abacusai.feature_distribution

## Classes

`FeatureDistribution` | For a single feature, how it has changed in the training data versus some specified window

## Module Contents

class abacusai.feature_distribution.FeatureDistribution(client, type=None, trainingDistribution=None, predictionDistribution=None, numericalTrainingDistribution=None, numericalPredictionDistribution=None, trainingStatistics=None, predictionStatistics=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  For a single feature, how it has changed in the training data versus some specified window

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - type (str) – Data type of values in each distribution, typically ‘categorical’ or ‘numerical’.

    - trainingDistribution (dict) – A dict describing the range of values in the training distribution.

    - predictionDistribution (dict) – A dict describing the range of values in the specified window.

    - numericalTrainingDistribution (dict) – A dict describing the summary statistics of the numerical training distribution.

    - numericalPredictionDistribution (dict) – A dict describing the summary statistics of the numerical prediction distribution.

    - trainingStatistics (dict) – A dict describing summary statistics of values in the training distribution.

    - predictionStatistics (dict) – A dict describing summary statistics of values in the specified window.

  type
  training_distribution
  prediction_distribution
  numerical_training_distribution
  numerical_prediction_distribution
  training_statistics
  prediction_statistics
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict